@@ -12,7 +12,11 @@ use der::Encodable;
 use std::{fs, path::Path, str};
 
 #[cfg(feature = "pem")]
-use {crate::pem, alloc::string::String, core::str::FromStr};
+use {
+    crate::{pem, LineEnding},
+    alloc::string::String,
+    core::str::FromStr,
+};
 
 /// Type label for PEM-encoded private keys.
 #[cfg(feature = "pem")]
@@ -33,12 +37,12 @@ impl PublicKeyDocument {
         SubjectPublicKeyInfo::try_from(self.0.as_slice()).expect("malformed PublicKeyDocument")
     }
 
-    /// Parse [`PublicKeyDocument`] from ASN.1 DER
+    /// Parse [`PublicKeyDocument`] from ASN.1 DER.
     pub fn from_der(bytes: &[u8]) -> Result<Self> {
         bytes.try_into()
     }
 
-    /// Parse [`PublicKeyDocument`] from PEM
+    /// Parse [`PublicKeyDocument`] from PEM.
     ///
     /// PEM-encoded public keys can be identified by the leading delimiter:
     ///
@@ -57,11 +61,19 @@ impl PublicKeyDocument {
         Self::from_der(&*der_bytes)
     }
 
-    /// Serialize [`PublicKeyDocument`] as PEM-encoded PKCS#8 string.
+    /// Serialize [`PublicKeyDocument`] as PEM-encoded PKCS#8 (SPKI) string.
     #[cfg(feature = "pem")]
     #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
     pub fn to_pem(&self) -> String {
-        pem::encode_string(PEM_TYPE_LABEL, &self.0).expect(error::PEM_ENCODING_MSG)
+        self.to_pem_with_le(LineEnding::default())
+    }
+
+    /// Serialize [`PublicKeyDocument`] as PEM-encoded PKCS#8 (SPKI) string
+    /// with the given [`LineEnding`].
+    #[cfg(feature = "pem")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
+    pub fn to_pem_with_le(&self, line_ending: LineEnding) -> String {
+        pem::encode_string(PEM_TYPE_LABEL, line_ending, &self.0).expect(error::PEM_ENCODING_MSG)
     }
 
     /// Load [`PublicKeyDocument`] from an ASN.1 DER-encoded file on the local
